Changes
*******

4.0 (2023-07-11)
================

- Add support for Python 3.11.

- Drop support for Python 2.7, 3.5, 3.6.

- Add support for Python 3.7, 3.8, 3.9, and 3.10.

- Drop support for Python 3.4.


3.0.1 (2018-01-12)
==================

- Rearrange tests such that Travis CI can pick up all functional tests too.

3.0.0 (2018-01-05)
==================

- Python 3 compatibility

1.2.1 (2016-02-15)
==================

- Update tests.

1.2 (2012-11-14)
================

- Add the layer directive to Traverser Components.

1.1 (2012-05-02)
================

- Use the component registration api of grokcore.component.

1.0 (2011-01-03)
================

- Factor out form grok base package.
